
.. include:: ../README.rst 
   :start-line: 0
   :end-line: 66

.. toctree::
   :maxdepth: 1
   :hidden:

   installation

.. toctree::
   :maxdepth: 1
   :caption: API usage examples
   :hidden:

   api_examples/exploratory_analysis
   api_examples/normalization_analysis
   api_examples/enrichment_analysis

.. toctree::
   :maxdepth: 1
   :caption: Example dataset (preprocessing)
   :hidden:

   api_examples/Download_PRIDE_data
   api_examples/ovarian_cancer

.. toctree::
   :maxdepth: 2
   :caption: Modules
   :hidden:

   reference/acore

Indices and tables
------------------
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. toctree::
   :maxdepth: 1
   :caption: MISC:
   :hidden:

   contributing
   authors
   history
   README.md


